==> jinrousiki-1.3.1.zip: jinrousiki-1.3.1/icon_upload_check.php <==
<?php
require_once(dirname(__FILE__) . '/include/functions.php');
require_once(dirname(__FILE__) . '/include/icon_data_check.php');

//å󳫻(إå˳ϤƤ)
session_start();
session_regenerate_id(); //å򿷤
$session_id = session_id();

// 顼ڡѥȥ
$title = 'Ͽ顼';

// եå
$icon_upload_page_url = $site_root . 'icon_upload.php';
if (strncmp(@$_SERVER['HTTP_REFERER'], $icon_upload_page_url , strlen($icon_upload_page_url)) != 0)
  OutputActionResult($title, '̵ʥǤ');

EncodePostData(); //ݥȤ줿ʸƥ󥳡ɤ

//̾򤫥å
$name = $_POST['name'];
if($name == '') OutputActionResult($title, '̾ϤƤ');

//̾ʸĹΥå
$name_length = strlen($name);
if($name_length > $USER_ICON->name){
  OutputActionResult($title, IconNameMaxLength());
}

//ե륵Υå
if($_FILES['file']['size'] == 0 || $_FILES['file']['size'] > $USER_ICON->size){
  OutputActionResult($title, 'ե륵 ' . IconFileSizeMax());
}

//եμΥå
switch($_FILES['file']['type']){
  case 'image/jpeg':
  case 'image/pjpeg':
    $ext = '.jpg';
    break;

  case 'image/gif':
    $ext = '.gif';
    break;

  case 'image/png':
  case 'image/x-png':
    $ext = '.png';
    break;

  default:
    OutputActionResult($title, $_FILES['file']['type'] .
		       ' : jpg, gif, png ʳΥեϿǤޤ');
    break;
}

//Υå
$color = $_POST['color'];
if(strlen($color) != 7 && ! preg_match('/^#[0123456789abcdefABCDEF]{6}/', $color)){
  OutputActionResult($title,
		     '꤬ޤ<br>'."\n" .
		     ' (㡧#6699CC) Τ褦 RGB 16ʿǹԤäƤ<br>'."\n" .
		     '줿  <span class="color">' . $color . '</span>');
}

//ι⤵å
list($width, $height) = getimagesize($_FILES['file']['tmp_name']);
if($width > $USER_ICON->width || $height > $USER_ICON->height){
  OutputActionResult($title, ' ' . IconSizeMax() . ' ϿǤޤ<br>'."\n" .
		     '줿ե  <span class="color"> ' . $width .
		     ', ⤵ ' . $height . '</span>');
}

$dbHandle = ConnectDatabase(); //DB ³

//̾ϿƤʤå
$sql = mysql_query('SELECT icon_name FROM user_icon');
if(in_array($name, mysql_fetch_assoc($sql))){
  OutputActionResult($title, 'Υ̾ϴϿƤޤ');
}
EscapeStrings(&$name);

if(! mysql_query('LOCK TABLES user_icon WRITE')){ //user_icon ơ֥å
  OutputActionResult($title, 'ФƤޤ<br>'."\n" .
		     '֤֤ƤϿ򤪴ꤤޤ');
}

//ϿͤĶƤʤå
//ϿƤ륢ʥС߽˼
$sql = mysql_query('SELECT icon_no FROM user_icon ORDER BY icon_no DESC');
$array = mysql_fetch_assoc($sql);
$icon_no = $array['icon_no'] + 1; //礭No + 1
if($icon_no >= $USER_ICON->number) OutputActionResult($title, 'ʾϿǤޤ', '', true);

//ե̾η򤽤
$file_name = sprintf("%03s%s", $icon_no, $ext);

//åץɤ줿եΥ顼å
if($_FILES['upfile']['error'][$i] != 0){
  OutputActionResult($title, 'åץɥ顼ȯޤ<br>'."\n" .
		     'ټ¹ԤƤ', '', true);
}

//եƥݥ꤫饳ԡ
if(! move_uploaded_file($_FILES['file']['tmp_name'], $ICON_CONF->path . '/' . $file_name)){
  OutputActionResult($title, 'Ͽ˼Ԥޤ<br>'."\n" .
		     'ټ¹ԤƤ', '', true);
}

//ǡ١Ͽ
mysql_query("INSERT INTO user_icon(icon_no, icon_name, icon_filename, icon_width, icon_height,
		color, session_id)
		VALUES($icon_no, '$name', '$file_name', $width, $height, '$color', '$session_id')");
mysql_query('COMMIT'); //ߥå
mysql_query('UNLOCK TABLES'); //å
DisconnectDatabase($dbHandle);

//ǧڡ
OutputHTMLHeader('桼󥢥åץɽ[ǧ]', 'icon_upload_check');
echo <<<EOF
</head>
<body>
<p>ե򥢥åץɤޤ<br>ʤǤޤ</p>
<img src="{$ICON_CONF->path}/$file_name" width="$width" height="$height"><br>
<table>
<tr><td>No. $icon_no <font color="$color"></font>$color<br></td></tr>
<tr><td>Ǥ</td></tr>
<tr><td><form method="POST" action="icon_upload_finish.php">
  <input type="hidden" name="entry" value="cancel">
  <input type="hidden" name="icon_no" value="$icon_no">
  <input type="submit" value="ʤ">
</form></td>
<td><form method="POST" action="icon_upload_finish.php">
  <input type="hidden" name="entry" value="success">
  <input type="hidden" name="icon_no" value="$icon_no">
  <input type="submit" value="Ͽλ">
</form></td></tr></table>
</body></html>

EOF;
?>

==> jinrousiki-1.3.3.zip: jinrousiki-1.3.3/icon_upload_check.php <==
<?php
require_once(dirname(__FILE__) . '/include/functions.php');
require_once(dirname(__FILE__) . '/include/icon_data_check.php');
if(FindDangerValue($_FILES)) die;

//å󳫻(إå˳ϤƤ)
session_start();
session_regenerate_id(); //å򿷤
$session_id = session_id();

// 顼ڡѥȥ
$title = 'Ͽ顼';

// եå
$icon_upload_page_url = $site_root . 'icon_upload.php';
if(strncmp(@$_SERVER['HTTP_REFERER'], $icon_upload_page_url , strlen($icon_upload_page_url)) != 0){
  OutputActionResult($title, '̵ʥǤ');
}
EncodePostData(); //ݥȤ줿ʸƥ󥳡ɤ

//̾򤫥å
$name = $_POST['name'];
if($name == '') OutputActionResult($title, '̾ϤƤ');

//̾ʸĹΥå
$name_length = strlen($name);
if($name_length > $USER_ICON->name){
  OutputActionResult($title, IconNameMaxLength());
}

//ե륵Υå
if($_FILES['file']['size'] == 0 || $_FILES['file']['size'] > $USER_ICON->size){
  OutputActionResult($title, 'ե륵 ' . IconFileSizeMax());
}

//եμΥå
switch($_FILES['file']['type']){
case 'image/jpeg':
case 'image/pjpeg':
  $ext = '.jpg';
  break;

case 'image/gif':
  $ext = '.gif';
  break;

case 'image/png':
case 'image/x-png':
  $ext = '.png';
  break;

default:
  OutputActionResult($title, $_FILES['file']['type'] .
		     ' : jpg, gif, png ʳΥեϿǤޤ');
  break;
}

//Υå
$color = $_POST['color'];
if(strlen($color) != 7 && ! preg_match('/^#[0123456789abcdefABCDEF]{6}/', $color)){
  OutputActionResult($title,
		     '꤬ޤ<br>'."\n" .
		     ' (㡧#6699CC) Τ褦 RGB 16ʿǹԤäƤ<br>'."\n" .
		     '줿  <span class="color">' . $color . '</span>');
}

//ι⤵å
list($width, $height) = getimagesize($_FILES['file']['tmp_name']);
if($width > $USER_ICON->width || $height > $USER_ICON->height){
  OutputActionResult($title, ' ' . IconSizeMax() . ' ϿǤޤ<br>'."\n" .
		     '줿ե  <span class="color"> ' . $width .
		     ', ⤵ ' . $height . '</span>');
}

$dbHandle = ConnectDatabase(); //DB ³

//̾ϿƤʤå
$sql = mysql_query('SELECT icon_name FROM user_icon');
if(in_array($name, mysql_fetch_assoc($sql))){
  OutputActionResult($title, 'Υ̾ϴϿƤޤ');
}
EscapeStrings(&$name);

if(! mysql_query('LOCK TABLES user_icon WRITE')){ //user_icon ơ֥å
  OutputActionResult($title, 'ФƤޤ<br>'."\n" .
		     '֤֤ƤϿ򤪴ꤤޤ');
}

//ϿͤĶƤʤå
//ϿƤ륢ʥС߽˼
$sql = mysql_query('SELECT icon_no FROM user_icon ORDER BY icon_no DESC');
$array = mysql_fetch_assoc($sql);
$icon_no = $array['icon_no'] + 1; //礭No + 1
if($icon_no >= $USER_ICON->number) OutputActionResult($title, 'ʾϿǤޤ', '', true);

//ե̾η򤽤
$file_name = sprintf("%03s%s", $icon_no, $ext);

//åץɤ줿եΥ顼å
if($_FILES['upfile']['error'][$i] != 0){
  OutputActionResult($title, 'åץɥ顼ȯޤ<br>'."\n" .
		     'ټ¹ԤƤ', '', true);
}

//եƥݥ꤫饳ԡ
if(! move_uploaded_file($_FILES['file']['tmp_name'], $ICON_CONF->path . '/' . $file_name)){
  OutputActionResult($title, 'Ͽ˼Ԥޤ<br>'."\n" .
		     'ټ¹ԤƤ', '', true);
}

//ǡ١Ͽ
mysql_query("INSERT INTO user_icon(icon_no, icon_name, icon_filename, icon_width, icon_height,
		color, session_id)
		VALUES($icon_no, '$name', '$file_name', $width, $height, '$color', '$session_id')");
mysql_query('COMMIT'); //ߥå
mysql_query('UNLOCK TABLES'); //å
DisconnectDatabase($dbHandle);

//ǧڡ
OutputHTMLHeader('桼󥢥åץɽ[ǧ]', 'icon_upload_check');
echo <<<EOF
</head>
<body>
<p>ե򥢥åץɤޤ<br>ʤǤޤ</p>
<img src="{$ICON_CONF->path}/$file_name" width="$width" height="$height"><br>
<table>
<tr><td>No. $icon_no <font color="$color"></font>$color<br></td></tr>
<tr><td>Ǥ</td></tr>
<tr><td><form method="POST" action="icon_upload_finish.php">
  <input type="hidden" name="entry" value="cancel">
  <input type="hidden" name="icon_no" value="$icon_no">
  <input type="submit" value="ʤ">
</form></td>
<td><form method="POST" action="icon_upload_finish.php">
  <input type="hidden" name="entry" value="success">
  <input type="hidden" name="icon_no" value="$icon_no">
  <input type="submit" value="Ͽλ">
</form></td></tr></table>
</body></html>

EOF;
?>
